abacusai.resolved_feature_group_template — AbacusAI documentation

# `abacusai.resolved_feature_group_template`

## Module Contents

### Classes

`ResolvedFeatureGroupTemplate` | Final SQL from resolving a feature group template.

class abacusai.resolved_feature_group_template.ResolvedFeatureGroupTemplate(client, featureGroupTemplateId=None, resolvedVariables=None, resolvedSql=None, templateSql=None, sqlError=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Final SQL from resolving a feature group template.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - featureGroupTemplateId (str) – Unique identifier for this feature group template.

    - resolvedVariables (dict) – Map from template variable names to parameters available during template resolution.

    - resolvedSql (str) – SQL resulting from resolving the SQL template by applying the resolved bindings.

    - templateSql (str) – SQL that can include variables to be replaced by values from the template config to resolve this template SQL into a valid SQL query for a feature group.

    - sqlError (str) – if invalid, the sql error message

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict